@@ -1,4 +1,4 @@
-# $Id: MemCachedClient.pm,v 1.3 2003/06/11 21:38:12 bradfitz Exp $
+# $Id: MemCachedClient.pm,v 1.4 2003/06/16 22:13:32 bradfitz Exp $
 #
 # Copyright (c) 2003  Brad Fitzpatrick <brad@danga.com>
 #
@@ -12,7 +12,7 @@ use Storable ();
 package MemCachedClient;
 
 use vars qw($VERSION);
-$VERSION = "1.0.1";
+$VERSION = "1.0.2";
 
 my %host_dead;   # host -> unixtime marked dead until
 my %cache_sock;  # host -> socket
@@ -313,6 +313,18 @@ value.  You may prefer, for example, to keep all of a given user's
 objects on the same memcache server, so you could use the user's
 unique id as the hash value.
 
+=item C<get_multi>
+
+my $hashref = $mem->get_multi(@keys);
+
+Retrieves multiple keys from the memcache doing just one query.
+Returns a hashref of key/value pairs that were available.
+
+This method is recommended over regular 'get' as it lowers the number
+of total packets flying around your network, reducing total latency,
+since your app doesn't have to wait for each round-trip of 'get'
+before sending the next one.
+
 =item C<set>
 
 $mem->set($key, $value);
